@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-sidecar-locals
 ;; Keywords: convenience
-;; Package-Version: 20250918.217
-;; Package-Revision: 94fc39a75a53
+;; Package-Version: 20251126.347
+;; Package-Revision: 33c52d010227
 ;; Package-Requires: ((emacs "27.1"))
 
 ;;; Commentary:
@@ -383,17 +383,17 @@ When NO-TEST is non-nil checking for existing paths is disabled."
   (declare (important-return-value t))
   (and
    ;; Not in the mini-buffer.
-   (not (minibufferp))
+   (null (minibufferp))
    ;; Not a special mode (package list, tabulated data ... etc)
    ;; Instead the buffer is likely derived from `text-mode' or `prog-mode'.
-   (not (derived-mode-p 'special-mode))
+   (null (derived-mode-p 'special-mode))
    ;; Not explicitly ignored.
-   (not (memq major-mode sidecar-locals-ignore-modes))
+   (null (memq major-mode sidecar-locals-ignore-modes))
    ;; Optionally check if a function is used.
    (or (null sidecar-locals-ignore-buffer)
        (cond
         ((functionp sidecar-locals-ignore-buffer)
-         (not (funcall sidecar-locals-ignore-buffer (current-buffer))))
+         (null (funcall sidecar-locals-ignore-buffer (current-buffer))))
         (t
          nil)))))
 
